@@ -18,9 +18,7 @@
 from __future__ import division, print_function, absolute_import
 
 import hypothesis.internal.conjecture.utils as d
-from hypothesis.types import RandomWithSeed
-from hypothesis.searchstrategy.strategies import SearchStrategy, \
-    MappedSearchStrategy
+from hypothesis.searchstrategy.strategies import SearchStrategy
 
 
 class BoolStrategy(SearchStrategy):
@@ -65,18 +63,6 @@ class JustStrategy(SearchStrategy):
         return self.value
 
 
-class RandomStrategy(MappedSearchStrategy):
-    """A strategy which produces Random objects.
-
-    The conditional distribution is simply a RandomWithSeed seeded with
-    a 128 bits of data chosen uniformly at random.
-
-    """
-
-    def pack(self, i):
-        return RandomWithSeed(i)
-
-
 class SampledFromStrategy(SearchStrategy):
     """A strategy which samples from a set of elements. This is essentially
     equivalent to using a OneOfStrategy over Just strategies but may be more
@@ -84,12 +70,11 @@ class SampledFromStrategy(SearchStrategy):
 
     The conditional distribution chooses uniformly at random from some
     non-empty subset of the elements.
-
     """
 
     def __init__(self, elements):
         SearchStrategy.__init__(self)
-        self.elements = d.check_sample(elements)
+        self.elements = d.check_sample(elements, 'sampled_from')
         assert self.elements
 
     def calc_has_reusable_values(self, recur):
